==> nextcloud-10.0.2.tar.bz2: nextcloud/apps/files_external/l10n/it.js <==
OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "Il recupero dei token di richiesta non è riuscito. Verifica che la chiave e il segreto dell'applicazione siano corretti.",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "Il recupero dei token di accesso non è riuscito. Verifica che la chiave e il segreto dell'applicazione siano corretti.",
    "Please provide a valid app key and secret." : "Fornisci chiave e segreto dell'applicazione validi.",
    "Step 1 failed. Exception: %s" : "Fase 1 non riuscita. Eccezione: %s",
    "Step 2 failed. Exception: %s" : "Fase 2 non riuscita. Eccezione: %s",
    "External storage" : "Archiviazione esterna",
    "Dropbox App Configuration" : "Configurazione applicazione Dropbox",
    "Google Drive App Configuration" : "Configurazione applicazione Google Drive",
    "Personal" : "Personale",
    "System" : "Sistema",
    "Grant access" : "Concedi l'accesso",
    "Error configuring OAuth1" : "Errore di configurazione OAuth1",
    "Error configuring OAuth2" : "Errore di configurazione OAuth2",
    "Generate keys" : "Genera la chiavi",
    "Error generating key pair" : "Errore durante la generazione della coppia di chiavi",
    "All users. Type to select user or group." : "Tutti gli utenti. Digita per selezionare utente o gruppo.",
    "(group)" : "(gruppo)",
    "Compatibility with Mac NFD encoding (slow)" : "Compatibilità con la codifica Mac NFD (lento)",
    "Admin defined" : "Definito dall'amministratore",
    "Saved" : "Salvato",
    "Saving..." : "Salvataggio in corso...",
    "Save" : "Salva",
    "Empty response from the server" : "Risposta vuota dal server",
    "Couldn't access. Please logout and login to activate this mount point" : "Impossibile accedere. Chiudi la sessione e accedi nuovamente per attivare questo punto di mount",
    "Couldn't get the information from the remote server: {code} {type}" : "Impossibile ottenere le informazioni dal server remoto: {code} {tipo}",
    "Couldn't get the list of external mount points: {type}" : "Impossibile ottenere l'elenco dei punti di mount esterni: {type}",
    "There was an error with message: " : "Si è verificato un errore con il messaggio:",
    "External mount error" : "Errore di mount esterno",
    "external-storage" : "archiviazione-esterna",
    "Couldn't get the list of Windows network drive mount points: empty response from the server" : "Impossibile ottenere l'elenco dei punti di mount delle unità di rete Windows: risposta vuota dal server",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Alcuni dei punti di mount esterni configurati non sono connessi. Fai clic sulle righe rosse per ulteriori informazioni",
    "Please enter the credentials for the {mount} mount" : "Digita le credenziali per montare {mount}",
    "Username" : "Nome utente",
    "Password" : "Password",
    "Credentials saved" : "Credenziali salvate",
    "Credentials saving failed" : "Salvataggio delle credenziali non riuscito",
    "Credentials required" : "Credenziali richieste",
    "Storage with id \"%i\" not found" : "Archiviazione con ID \"%i\" non trovata",
    "Invalid backend or authentication mechanism class" : "Motore o classe del meccanismo di autenticazione non valido",
    "Invalid mount point" : "Punto di mount non valido",
    "Objectstore forbidden" : "Objectstore vietato",
    "Invalid storage backend \"%s\"" : "Motore di archiviazione \"%s\" non valido",
    "Not permitted to use backend \"%s\"" : "Utilizzo del motore \"%s\" non permesso",
    "Not permitted to use authentication mechanism \"%s\"" : "Utilizzo del meccanismo di autenticazione \"%s\" non permesso",
    "Unsatisfied backend parameters" : "Parametri del motore non soddisfatti",
    "Unsatisfied authentication mechanism parameters" : "Parametri del meccanismo di autenticazione non soddisfatti",
    "Insufficient data: %s" : "Dati insufficienti: %s",
    "%s" : "%s",
    "Storage with id \"%i\" is not user editable" : "L'archiviazione con ID \"%i\" non è modificabile dall'utente",
    "Access key" : "Chiave di accesso",
    "Secret key" : "Chiave segreta",
    "Builtin" : "Integrata",
    "None" : "Nessuno",
    "OAuth1" : "OAuth1",
    "App key" : "Chiave applicazione",
    "App secret" : "Segreto applicazione",
    "OAuth2" : "OAuth2",
    "Client ID" : "ID client",
    "Client secret" : "Segreto del client",
    "OpenStack" : "OpenStack",
    "Tenant name" : "Nome tenant",
    "Identity endpoint URL" : "URL endpoint delle identità",
    "Rackspace" : "Rackspace",
    "API key" : "Chiave API",
    "Global credentials" : "Credenziali globali",
    "Log-in credentials, save in database" : "Credenziali di accesso, salva nel database",
    "Username and password" : "Nome utente e password",
    "Log-in credentials, save in session" : "Credenziali di accesso, salva nella sessione",
    "User entered, store in database" : "Inserite dall'utente, salva nel database",
    "RSA public key" : "Chiave pubblica RSA",
    "Public key" : "Chiave pubblica",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Nome host",
    "Port" : "Porta",
    "Region" : "Regione",
    "Enable SSL" : "Abilita SSL",
    "Enable Path Style" : "Abilita stile percorsi",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Sottocartella remota",
    "Secure https://" : "Sicuro https://",
    "Dropbox" : "Dropbox",
    "FTP" : "FTP",
    "Host" : "Host",
    "Secure ftps://" : "Sicuro ftps://",
    "Google Drive" : "Google Drive",
    "Local" : "Locale",
    "Location" : "Posizione",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Radice",
    "SFTP with secret key login" : "SFTP con accesso a chiave segreta",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Condividi",
    "Domain" : "Dominio",
    "SMB / CIFS using OC login" : "SMB / CIFS utilizzando le credenziali di OC",
    "Username as share" : "Nome utente come condivisione",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Nome servizio",
    "Request timeout (seconds)" : "Tempo massimo della richiesta (secondi)",
    "External storages" : "Archiviazioni esterne",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Il supporto cURL di PHP non è abilitato o installato. Impossibile montare %s. Chiedi al tuo amministratore di sistema di installarlo.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Il supporto FTP in PHP non è abilitato o installato. Impossibile montare %s. Chiedi al tuo amministratore di sistema di installarlo.",
    "\"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "\"%s\" non è installato. Impossibile montare %s. Chiedi al tuo amministratore di sistema di installarlo.",
    "No external storage configured" : "Nessuna archiviazione esterna configurata",
    "You can add external storages in the personal settings" : "Puoi aggiungere archiviazioni esterne nelle impostazioni personali",
    "Name" : "Nome",
    "Storage type" : "Tipo di archiviazione",
    "Scope" : "Ambito",
    "Enable encryption" : "Abilita cifratura",
    "Enable previews" : "Abilita le anteprime",
    "Enable sharing" : "Abilita condivisione",
    "Check for changes" : "Controlla le modifiche",
    "Never" : "Mai",
    "Once every direct access" : "Una volta per ogni accesso diretto",
    "Folder name" : "Nome della cartella",
    "Authentication" : "Autenticazione",
    "Configuration" : "Configurazione",
    "Available for" : "Disponibile per",
    "Add storage" : "Aggiungi archiviazione",
    "Advanced settings" : "Impostazioni avanzate",
    "Delete" : "Elimina",
    "Allow users to mount external storage" : "Consenti agli utenti di montare archiviazioni esterne",
    "Allow users to mount the following external storage" : "Consenti agli utenti di montare la seguente archiviazione esterna",
    "Couldn't get the information from the ownCloud server: {code} {type}" : "Impossibile ottenere le informazioni dal server ownCloud: {code} {type}",
    "Access granted" : "Accesso accordato",
    "Global Credentials" : "Credenziali globali",
    "ownCloud" : "ownCloud",
    "<b>Note:</b> " : "<b>Nota:</b>",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Nota:</b> il supporto a cURL di PHP non è abilitato o installato. Impossibile montare %s. Chiedi al tuo amministratore di sistema di installarlo.",
    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Nota:</b> il supporto a FTP in PHP non è abilitato o installato. Impossibile montare %s. Chiedi al tuo amministratore di sistema di installarlo.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Nota:</b> \"%s\" non è installato. Impossibile montare %s. Chiedi al tuo amministratore di sistema di installarlo.",
    "External Storage" : "Archiviazione esterna"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.5.tar.bz2: nextcloud/apps/files_external/l10n/it.js <==
OC.L10N.register(
    "files_external",
    {
    "External storages" : "Archiviazioni esterne",
    "Personal" : "Personale",
    "System" : "Sistema",
    "Grant access" : "Concedi l'accesso",
    "Error configuring OAuth1" : "Errore di configurazione OAuth1",
    "Please provide a valid app key and secret." : "Fornisci chiave e segreto dell'applicazione validi.",
    "Error configuring OAuth2" : "Errore di configurazione OAuth2",
    "Generate keys" : "Genera la chiavi",
    "Error generating key pair" : "Errore durante la generazione della coppia di chiavi",
    "All users. Type to select user or group." : "Tutti gli utenti. Digita per selezionare utente o gruppo.",
    "(group)" : "(gruppo)",
    "Compatibility with Mac NFD encoding (slow)" : "Compatibilità con la codifica Mac NFD (lento)",
    "Admin defined" : "Definito dall'amministratore",
    "Are you sure you want to delete this external storage" : "Sei sicuro di voler eliminare questa archiviazione esterna?",
    "Delete storage?" : "Vuoi eliminare l'archiviazione?",
    "Saved" : "Salvato",
    "Saving..." : "Salvataggio in corso...",
    "Save" : "Salva",
    "Empty response from the server" : "Risposta vuota dal server",
    "Couldn't access. Please log out and in again to activate this mount point" : "Impossibile accedere. Chiudi la sessione e accedi nuovamente per attivare questo punto di mount",
    "Couldn't get the information from the remote server: {code} {type}" : "Impossibile ottenere le informazioni dal server remoto: {code} {tipo}",
    "Couldn't get the list of external mount points: {type}" : "Impossibile ottenere l'elenco dei punti di mount esterni: {type}",
    "There was an error with message: " : "Si è verificato un errore con il messaggio:",
    "External mount error" : "Errore di mount esterno",
    "external-storage" : "archiviazione-esterna",
    "Couldn't fetch list of Windows network drive mount points: Empty response from server" : "Impossibile ottenere l'elenco dei punti di mount delle unità di rete Windows: risposta vuota dal server",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Alcuni dei punti di mount esterni configurati non sono connessi. Fai clic sulle righe rosse per ulteriori informazioni",
    "Please enter the credentials for the {mount} mount" : "Digita le credenziali per montare {mount}",
    "Username" : "Nome utente",
    "Password" : "Password",
    "Credentials saved" : "Credenziali salvate",
    "Credentials saving failed" : "Salvataggio delle credenziali non riuscito",
    "Credentials required" : "Credenziali richieste",
    "Storage with ID \"%d\" not found" : "Archiviazione con ID \"%d\" non trovata",
    "Invalid backend or authentication mechanism class" : "Motore o classe del meccanismo di autenticazione non valido",
    "Invalid mount point" : "Punto di mount non valido",
    "Objectstore forbidden" : "Objectstore vietato",
    "Invalid storage backend \"%s\"" : "Motore di archiviazione \"%s\" non valido",
    "Not permitted to use backend \"%s\"" : "Utilizzo del motore \"%s\" non permesso",
    "Not permitted to use authentication mechanism \"%s\"" : "Utilizzo del meccanismo di autenticazione \"%s\" non permesso",
    "Unsatisfied backend parameters" : "Parametri del motore non soddisfatti",
    "Unsatisfied authentication mechanism parameters" : "Parametri del meccanismo di autenticazione non soddisfatti",
    "Insufficient data: %s" : "Dati insufficienti: %s",
    "%s" : "%s",
    "Storage with ID \"%d\" is not user editable" : "Archiviazione con ID \"%d\" non modificabile dall'utente",
    "Access key" : "Chiave di accesso",
    "Secret key" : "Chiave segreta",
    "Builtin" : "Integrata",
    "None" : "Nessuno",
    "OAuth1" : "OAuth1",
    "App key" : "Chiave applicazione",
    "App secret" : "Segreto applicazione",
    "OAuth2" : "OAuth2",
    "Client ID" : "ID client",
    "Client secret" : "Segreto del client",
    "OpenStack" : "OpenStack",
    "Tenant name" : "Nome tenant",
    "Identity endpoint URL" : "URL endpoint delle identità",
    "Rackspace" : "Rackspace",
    "API key" : "Chiave API",
    "Global credentials" : "Credenziali globali",
    "Log-in credentials, save in database" : "Credenziali di accesso, salva nel database",
    "Username and password" : "Nome utente e password",
    "Log-in credentials, save in session" : "Credenziali di accesso, salva nella sessione",
    "User entered, store in database" : "Inserite dall'utente, salva nel database",
    "RSA public key" : "Chiave pubblica RSA",
    "Public key" : "Chiave pubblica",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Nome host",
    "Port" : "Porta",
    "Region" : "Regione",
    "Enable SSL" : "Abilita SSL",
    "Enable Path Style" : "Abilita stile percorsi",
    "Legacy (v2) authentication" : "Autenticazione tradizionale (v2)",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Sottocartella remota",
    "Secure https://" : "Sicuro https://",
    "FTP" : "FTP",
    "Host" : "Host",
    "Secure ftps://" : "Sicuro ftps://",
    "Local" : "Locale",
    "Location" : "Posizione",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Radice",
    "SFTP with secret key login" : "SFTP con accesso a chiave segreta",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Condividi",
    "Domain" : "Dominio",
    "SMB / CIFS using OC login" : "SMB / CIFS utilizzando le credenziali di OC",
    "Username as share" : "Nome utente come condivisione",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Nome servizio",
    "Request timeout (seconds)" : "Tempo massimo della richiesta (secondi)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Il supporto cURL di PHP non è abilitato o installato. Impossibile montare %s. Chiedi al tuo amministratore di sistema di installarlo.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Il supporto FTP in PHP non è abilitato o installato. Impossibile montare %s. Chiedi al tuo amministratore di sistema di installarlo.",
    "\"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "\"%s\" non è installato. Impossibile montare %s. Chiedi al tuo amministratore di sistema di installarlo.",
    "No external storage configured" : "Nessuna archiviazione esterna configurata",
    "You can add external storages in the personal settings" : "Puoi aggiungere archiviazioni esterne nelle impostazioni personali",
    "Name" : "Nome",
    "Storage type" : "Tipo di archiviazione",
    "Scope" : "Ambito",
    "Enable encryption" : "Abilita cifratura",
    "Enable previews" : "Abilita le anteprime",
    "Enable sharing" : "Abilita condivisione",
    "Check for changes" : "Controlla le modifiche",
    "Never" : "Mai",
    "Once every direct access" : "Una volta per ogni accesso diretto",
    "Folder name" : "Nome della cartella",
    "External storage" : "Archiviazione esterna",
    "Authentication" : "Autenticazione",
    "Configuration" : "Configurazione",
    "Available for" : "Disponibile per",
    "Add storage" : "Aggiungi archiviazione",
    "Advanced settings" : "Impostazioni avanzate",
    "Delete" : "Elimina",
    "Allow users to mount external storage" : "Consenti agli utenti di montare archiviazioni esterne",
    "Allow users to mount the following external storage" : "Consenti agli utenti di montare la seguente archiviazione esterna",
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "Il recupero dei token di richiesta non è riuscito. Verifica che la chiave e il segreto dell'applicazione siano corretti.",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "Il recupero dei token di accesso non è riuscito. Verifica che la chiave e il segreto dell'applicazione siano corretti.",
    "Step 1 failed. Exception: %s" : "Fase 1 non riuscita. Eccezione: %s",
    "Step 2 failed. Exception: %s" : "Fase 2 non riuscita. Eccezione: %s",
    "Dropbox App Configuration" : "Configurazione applicazione Dropbox",
    "Google Drive App Configuration" : "Configurazione applicazione Google Drive",
    "Storage with id \"%i\" not found" : "Archiviazione con ID \"%i\" non trovata",
    "Storage with id \"%i\" is not user editable" : "L'archiviazione con ID \"%i\" non è modificabile dall'utente",
    "Dropbox" : "Dropbox",
    "Google Drive" : "Google Drive"
},
"nplurals=2; plural=(n != 1);");
